pub struct Recording { /* private fields */ }Expand description
A recording of events from a Recorder.
Implementations
Sourceimpl Recording
impl Recording
Sourcepub fn span(&self) -> Span
pub fn span(&self) -> Span
Return a span, which will record events to this recording when entered.
Uses parent: None so that this span is always a root span. Without this,
contextual parentage would cause a spawned actor’s recording span to become
a child of the spawning actor’s recording span (via Instance::start()’s
.instrument(Span::current())), causing events to leak into the parent
actor’s flight recorder.